@@ -5,6 +5,7 @@ import os, os.path, sys, re, zlib, glob
 from pack_file import PackFile
 from obj_id import ObjId
 from struni import struni
+from vf_template import VF_TEMPLATE
 
 def empty_if_none_deko(org_meth):
     def wrapper(gitdiscribe_ob):
@@ -87,15 +88,56 @@ class Gitdiscribe(object):
     def tag_number_long(self):
         return re.sub('^\D+', '', self.tag_long)
 
-    def write_version_file(self, path='version.py'):
+    @property
+    @empty_if_none_deko
+    def sha1(self):
+        return self._tag['commit']
+
+    @property
+    @empty_if_none_deko
+    def sha1_short(self):
+        return self._tag['commit'][0:7]
+
+    @property
+    @empty_if_none_deko
+    def revision(self):
+        return self._tag['dist']
+
+    @property
+    def version(self):
+        '''returns a 3 elements tuple of ints even if there is not one digit in the tag'''
+        if not hasattr(self, '_version'):
+            mo = re.match('[\d.]+', self.tag_number)
+            nums = mo.group(0).split('.') if mo else []
+            self._version = tuple([int(n) for n in  nums] + ([0] * (3 - len(nums))))
+        return self._version
+
+    @property
+    def major_version(self):
+        return self._version[0]
+
+    @property
+    def minor_version(self):
+        return self._version[1]
+
+    @property
+    def sub_version(self):
+        return self._version[2]
+
+    def write_version_file(self, path='version.py', template=VF_TEMPLATE, template_path=None):
         if not self.tag:
+            print('gitdiscribe: No version file written.')
             return
-        t = self._tag
+        if template_path:
+            with open(template_path) as fh:
+                template = fh.read()
+        fields = ('tag', 'tag_long', 'tag_medium', 'tag_short', 'tag_number', 'tag_number_long',
+                  'tag_number_medium', 'tag_number_short', 'sha1', 'sha1_short', 'revision',
+                  'version', 'major_version', 'minor_version', 'sub_version')
+        for f in fields:
+            template = template.replace('{{{0}}}'.format(f), str(getattr(self, f)))
         with open(path, 'w') as fh:
-            fh.write('''# written by gitdiscribe
-FULL_VERSION = "{0}"
-VERSION = "{1}"
-GIT_REVISION = "{2}"'''.format(self.tag_number, self.tag_number_short, t['commit'][0:7]))
+            fh.write(template)
 
     def get_packed_refs(self):
         self.packed_refs = {}
